==> applet-web-boot-starter-0.0.6-sources.jar: cn/sinozg/applet/common/config/SystemWebConfig.java <==
package cn.sinozg.applet.common.config;

import cn.sinozg.applet.common.filter.WrapperFilter;
import cn.sinozg.applet.common.interceptor.ParamsInterceptor;
import cn.sinozg.applet.common.properties.ApiUrlValue;
import cn.sinozg.applet.common.properties.AppValue;
import cn.sinozg.applet.common.service.FrameworkAuthService;
import cn.sinozg.applet.common.service.FrameworkInitDataService;
import org.apache.commons.collections4.CollectionUtils;
import org.jetbrains.annotations.NotNull;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

import javax.annotation.Resource;

/**
* 鉴权 全局拦截器
* @Author: xyb
* @Description:
* @Date: 2022-11-14 下午 10:09
**/
@Configuration
public class SystemWebConfig implements WebMvcConfigurer {

    @Resource
    private AppValue app;

    @Resource
    private ParamsInterceptor paramsInterceptor;

    @Resource
    private FrameworkInitDataService initDataService;

    @Resource
    private FrameworkAuthService authService;

    private final Logger log = LoggerFactory.getLogger(SystemWebConfig.class);
    @Override
    public void addInterceptors(@NotNull InterceptorRegistry registry) {
        log.info("addInterceptors");
        // token 拦截
        ApiUrlValue apiUrl = app.getApiUrl();
        HandlerInterceptor authInterceptor = authService.authInterceptor();
        if (authInterceptor != null) {
            registry.addInterceptor(authInterceptor)
                    .addPathPatterns(apiUrl.getAuthPatterns())
                    .excludePathPatterns(apiUrl.getAuthExcludePath());
        }
        // 参数校验
        if (CollectionUtils.isNotEmpty(apiUrl.getParamsPatterns())) {
            registry.addInterceptor(paramsInterceptor).addPathPatterns(apiUrl.getParamsPatterns());
        }
        initDataService.addCustomInterceptor(registry);
    }

    /**
     * http请求 包装
     * @return 过滤器
     */
    @Bean
    public FilterRegistrationBean<WrapperFilter> registrationBean (){
        ApiUrlValue apiUrl = app.getApiUrl();
        FilterRegistrationBean<WrapperFilter> bean = new FilterRegistrationBean<>();
        bean.setFilter(new WrapperFilter(app));
        bean.addUrlPatterns(apiUrl.getWrapperUrl());
        return bean;
    }
}

==> applet-web-boot-starter-3.0.1-sources.jar: cn/sinozg/applet/common/config/SystemWebConfig.java <==
package cn.sinozg.applet.common.config;

import cn.sinozg.applet.common.filter.WrapperFilter;
import cn.sinozg.applet.common.interceptor.ParamsInterceptor;
import cn.sinozg.applet.common.properties.ApiUrlValue;
import cn.sinozg.applet.common.properties.AppValue;
import cn.sinozg.applet.common.service.FrameworkAuthService;
import cn.sinozg.applet.common.service.FrameworkInitDataService;
import org.apache.commons.collections4.CollectionUtils;
import org.jetbrains.annotations.NotNull;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

import jakarta.annotation.Resource;

/**
* 鉴权 全局拦截器
* @Author: xyb
* @Description:
* @Date: 2022-11-14 下午 10:09
**/
@Configuration
public class SystemWebConfig implements WebMvcConfigurer {

    @Resource
    private AppValue app;

    @Resource
    private ParamsInterceptor paramsInterceptor;

    @Resource
    private FrameworkInitDataService initDataService;

    @Resource
    private FrameworkAuthService authService;

    private final Logger log = LoggerFactory.getLogger(SystemWebConfig.class);
    @Override
    public void addInterceptors(@NotNull InterceptorRegistry registry) {
        log.info("addInterceptors");
        // token 拦截
        ApiUrlValue apiUrl = app.getApiUrl();
        HandlerInterceptor authInterceptor = authService.authInterceptor();
        if (authInterceptor != null) {
            registry.addInterceptor(authInterceptor)
                    .addPathPatterns(apiUrl.getAuthPatterns())
                    .excludePathPatterns(apiUrl.getAuthExcludePath());
        }
        // 参数校验
        if (CollectionUtils.isNotEmpty(apiUrl.getParamsPatterns())) {
            registry.addInterceptor(paramsInterceptor).addPathPatterns(apiUrl.getParamsPatterns());
        }
        initDataService.addCustomInterceptor(registry);
    }

    /**
     * http请求 包装
     * @return 过滤器
     */
    @Bean
    public FilterRegistrationBean<WrapperFilter> registrationBean (){
        ApiUrlValue apiUrl = app.getApiUrl();
        FilterRegistrationBean<WrapperFilter> bean = new FilterRegistrationBean<>();
        bean.setFilter(new WrapperFilter(app));
        bean.addUrlPatterns(apiUrl.getWrapperUrl());
        return bean;
    }
}
